ChartSeriesOptions class

Possible options for Series Charts.

Inheritance

Constructors

ChartSeriesOptions()

Properties

fillLines ↔ bool
Draw lines area, filling the area beneath them.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onClick ↔ void Function(List? activeItems, List? xItems, List? yItems)?
Callback for click events.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortCategories ↔ bool
Sort Categories/Series.keys when showing them in the Chart.
getter/setter pairinherited
steppedLines ↔ bool
Draw stepped lines.
getter/setter pair
straightLines ↔ bool
Draw straight lines instead of smooth lines.
getter/setter pair
verticalLines ↔ List<VerticalLine>?
The vertical lines of the chart.
getter/setter pairinherited
verticalLinesDefaultColor ↔ String
The vertical lines default color.
getter/setter pairinherited
xAxisMax ↔ num?
Maximum value for X axis.
getter/setter pairinherited
xAxisMin ↔ num?
Minimum value for X axis.
getter/setter pairinherited
xAxisMinMax → List<num>?
Returns X axis minimum and maximum values.
no setterinherited
yAxisMax ↔ num?
Maximum value for Y axis.
getter/setter pairinherited
yAxisMin ↔ num?
Minimum value for Y axis.
getter/setter pairinherited
yAxisMinMax → List<num>?
Returns Y axis minimum and maximum values.
no setterinherited

Methods

copy() → ChartSeriesOptions
Copies this instance.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited